@@ -29,8 +29,10 @@ from .type_defs import (
     GetAttendeeResponseTypeDef,
     GetMeetingResponseTypeDef,
     ListAttendeesResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
     MeetingFeaturesConfigurationTypeDef,
     NotificationsConfigurationTypeDef,
+    TagTypeDef,
     TranscriptionConfigurationTypeDef,
     UpdateAttendeeCapabilitiesResponseTypeDef,
 )
@@ -53,9 +55,11 @@ class Exceptions:
     ForbiddenException: Type[BotocoreClientError]
     LimitExceededException: Type[BotocoreClientError]
     NotFoundException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
     ServiceFailureException: Type[BotocoreClientError]
     ServiceUnavailableException: Type[BotocoreClientError]
     ThrottlingException: Type[BotocoreClientError]
+    TooManyTagsException: Type[BotocoreClientError]
     UnauthorizedException: Type[BotocoreClientError]
     UnprocessableEntityException: Type[BotocoreClientError]
 
@@ -142,7 +146,8 @@ class ChimeSDKMeetingsClient(BaseClient):
         NotificationsConfiguration: NotificationsConfigurationTypeDef = ...,
         MeetingFeatures: MeetingFeaturesConfigurationTypeDef = ...,
         PrimaryMeetingId: str = ...,
-        TenantIds: Sequence[str] = ...
+        TenantIds: Sequence[str] = ...,
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateMeetingResponseTypeDef:
         """
         Creates a new Amazon Chime SDK meeting in the specified media Region with no
@@ -163,7 +168,8 @@ class ChimeSDKMeetingsClient(BaseClient):
         MeetingFeatures: MeetingFeaturesConfigurationTypeDef = ...,
         NotificationsConfiguration: NotificationsConfigurationTypeDef = ...,
         PrimaryMeetingId: str = ...,
-        TenantIds: Sequence[str] = ...
+        TenantIds: Sequence[str] = ...,
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateMeetingWithAttendeesResponseTypeDef:
         """
         Creates a new Amazon Chime SDK meeting in the specified media Region, with
@@ -231,6 +237,14 @@ class ChimeSDKMeetingsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#list_attendees)
         """
 
+    def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
+        """
+        Returns a list of the tags available for the specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#list_tags_for_resource)
+        """
+
     def start_meeting_transcription(
         self, *, MeetingId: str, TranscriptionConfiguration: TranscriptionConfigurationTypeDef
     ) -> EmptyResponseMetadataTypeDef:
@@ -249,6 +263,22 @@ class ChimeSDKMeetingsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#stop_meeting_transcription)
         """
 
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
+        """
+        The resource that supports tags.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.tag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#tag_resource)
+        """
+
+    def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
+        """
+        Removes the specified tags from the specified resources.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.untag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#untag_resource)
+        """
+
     def update_attendee_capabilities(
         self, *, MeetingId: str, AttendeeId: str, Capabilities: AttendeeCapabilitiesTypeDef
     ) -> UpdateAttendeeCapabilitiesResponseTypeDef:
