@@ -43,6 +43,7 @@ __all__ = (
     "CreateAttendeeErrorTypeDef",
     "ResponseMetadataTypeDef",
     "NotificationsConfigurationTypeDef",
+    "TagTypeDef",
     "DeleteAttendeeRequestRequestTypeDef",
     "DeleteMeetingRequestRequestTypeDef",
     "EngineTranscribeMedicalSettingsTypeDef",
@@ -50,8 +51,10 @@ __all__ = (
     "GetAttendeeRequestRequestTypeDef",
     "GetMeetingRequestRequestTypeDef",
     "ListAttendeesRequestRequestTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "MediaPlacementTypeDef",
     "StopMeetingTranscriptionRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
     "AttendeeTypeDef",
     "CreateAttendeeRequestItemTypeDef",
     "CreateAttendeeRequestRequestTypeDef",
@@ -59,6 +62,8 @@ __all__ = (
     "BatchUpdateAttendeeCapabilitiesExceptRequestRequestTypeDef",
     "MeetingFeaturesConfigurationTypeDef",
     "EmptyResponseMetadataTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TranscriptionConfigurationTypeDef",
     "BatchCreateAttendeeResponseTypeDef",
     "CreateAttendeeResponseTypeDef",
@@ -130,6 +135,14 @@ NotificationsConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+TagTypeDef = TypedDict(
+    "TagTypeDef",
+    {
+        "Key": str,
+        "Value": str,
+    },
+)
+
 DeleteAttendeeRequestRequestTypeDef = TypedDict(
     "DeleteAttendeeRequestRequestTypeDef",
     {
@@ -228,6 +241,13 @@ class ListAttendeesRequestRequestTypeDef(
     pass
 
 
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+    },
+)
+
 MediaPlacementTypeDef = TypedDict(
     "MediaPlacementTypeDef",
     {
@@ -250,6 +270,14 @@ StopMeetingTranscriptionRequestRequestTypeDef = TypedDict(
     },
 )
 
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "TagKeys": Sequence[str],
+    },
+)
+
 AttendeeTypeDef = TypedDict(
     "AttendeeTypeDef",
     {
@@ -337,6 +365,22 @@ EmptyResponseMetadataTypeDef = TypedDict(
     },
 )
 
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": List[TagTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+)
+
 TranscriptionConfigurationTypeDef = TypedDict(
     "TranscriptionConfigurationTypeDef",
     {
@@ -412,6 +456,7 @@ _OptionalCreateMeetingRequestRequestTypeDef = TypedDict(
         "MeetingFeatures": MeetingFeaturesConfigurationTypeDef,
         "PrimaryMeetingId": str,
         "TenantIds": Sequence[str],
+        "Tags": Sequence[TagTypeDef],
     },
     total=False,
 )
@@ -440,6 +485,7 @@ _OptionalCreateMeetingWithAttendeesRequestRequestTypeDef = TypedDict(
         "NotificationsConfiguration": NotificationsConfigurationTypeDef,
         "PrimaryMeetingId": str,
         "TenantIds": Sequence[str],
+        "Tags": Sequence[TagTypeDef],
     },
     total=False,
 )
@@ -463,6 +509,7 @@ MeetingTypeDef = TypedDict(
         "MeetingFeatures": MeetingFeaturesConfigurationTypeDef,
         "PrimaryMeetingId": str,
         "TenantIds": List[str],
+        "MeetingArn": str,
     },
     total=False,
 )
